summaryrefslogtreecommitdiffstats
path: root/kmobile/kmobile.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmobile/kmobile.cpp')
-rw-r--r--kmobile/kmobile.cpp44
1 files changed, 22 insertions, 22 deletions
diff --git a/kmobile/kmobile.cpp b/kmobile/kmobile.cpp
index 07fa1582..a34215e4 100644
--- a/kmobile/kmobile.cpp
+++ b/kmobile/kmobile.cpp
@@ -77,7 +77,7 @@ KMobile::KMobile()
connect(m_view, TQT_SIGNAL(signalChangeStatusbar(const TQString&)),
this, TQT_SLOT(changeStatusbar(const TQString&)));
// restore all configured devices
restoreAll();
// setup the system tray
@@ -105,13 +105,13 @@ void KMobile::setupActions()
KStdAction::preferences(this, TQT_SLOT(optionsPreferences()), actionCollection());
new KAction(i18n("&Add Device..."), "folder_new", 0,
- this, TQT_SLOT(addDevice()), actionCollection(), "device_add");
- new KAction( KGuiItem( i18n("&Remove Device"), "edittrash", i18n("Remove this device") ),
- "Delete", this, TQT_SLOT(removeDevice()), actionCollection(), "device_remove");
+ this, TQT_SLOT(addDevice()), actionCollection(), "tqdevice_add");
+ new KAction( KGuiItem( i18n("&Remove Device"), "edittrash", i18n("Remove this tqdevice") ),
+ "Delete", this, TQT_SLOT(removeDevice()), actionCollection(), "tqdevice_remove");
new KAction(i18n("Re&name Device..."), 0, Key_F2,
- this, TQT_SLOT(renameDevice()), actionCollection(), "device_rename");
+ this, TQT_SLOT(renameDevice()), actionCollection(), "tqdevice_rename");
new KAction(i18n("&Configure Device..."), "configure", 0,
- this, TQT_SLOT(configDevice()), actionCollection(), "device_configure");
+ this, TQT_SLOT(configDevice()), actionCollection(), "tqdevice_configure");
createGUI();
@@ -240,7 +240,7 @@ void KMobile::optionsPreferences()
void KMobile::renameDevice()
{
// rename the current selected device
TQIconViewItem *item = m_view->currentItem();
if (item)
item->rename();
@@ -258,7 +258,7 @@ void KMobile::addDevice()
dialog->setCaption( i18n("Add New Mobile or Portable Device") );
- dialog->helpText->setText( i18n("Please select the category to which your new device belongs:") );
+ dialog->helpText->setText( i18n("Please select the category to which your new tqdevice belongs:") );
dialog->addButton->setText( i18n("&Scan for New Devices...") );
dialog->addButton->setDisabled(true);
dialog->iconView->connect( dialog->iconView, TQT_SIGNAL(doubleClicked(TQIconViewItem*)),
@@ -297,7 +297,7 @@ void KMobile::addDevice()
ptr = list[index];
// add the new device to the list
if (!m_view->addNewDevice(m_config, ptr)) {
KMessageBox::error(this,
TQString("<qt>KMobile could not load the <b>%1</b> Device Driver.<p>"
@@ -313,34 +313,34 @@ void KMobile::addDevice()
#if 0
/*
* show dialog to user, in which he may choose and select one of the already
* configured mobile devices.
*/
-KMobileDevice * KMobileFactory::chooseDeviceDialog( TQWidget *parent,
+KMobileDevice * KMobileFactory::chooseDeviceDialog( TQWidget *tqparent,
enum KMobileDevice::ClassType /*type*/, enum KMobileDevice::Capabilities /*caps*/ )
{
int num;
- m_parent = parent;
+ m_tqparent = tqparent;
- // do we already have some devices configured ?
+ // do we already have some tqdevices configured ?
num = readDevicesList();
if (!num) {
int answ;
- answ = KMessageBox::questionYesNo(parent,
- i18n( "<qt>You have no mobile devices configured yet.<p>"
- "Do you want to add a device now ?</qt>" ),
+ answ = KMessageBox::questionYesNo(tqparent,
+ i18n( "<qt>You have no mobile tqdevices configured yet.<p>"
+ "Do you want to add a tqdevice now ?</qt>" ),
i18n( "KDE Mobile Device Access" ), KStdGuiItem::add(), i18n("Do Not Add") );
if (answ != KMessageBox::Yes)
return 0L;
- // add a new device
- addDeviceDialog(parent);
+ // add a new tqdevice
+ addDeviceDialog(tqparent);
}
num = readDevicesList();
if (!num)
return 0L;
- // let the user select one of the configured devices
- KMobile_selectiondialog *dialog = new KMobile_selectiondialog(parent);
+ // let the user select one of the configured tqdevices
+ KMobile_selectiondialog *dialog = new KMobile_selectiondialog(tqparent);
if (!dialog)
return 0L;
@@ -384,7 +384,7 @@ KMobileDevice * KMobileFactory::chooseDeviceDialog( TQWidget *parent,
void KMobile::removeDevice()
{
// remove the current selected device
TQIconViewItem *item = m_view->currentItem();
if (item)
m_view->removeDevice( item->text() );
@@ -392,7 +392,7 @@ void KMobile::removeDevice()
void KMobile::configDevice()
{
// configure the current selected device
TQIconViewItem *item = m_view->currentItem();
if (item)
m_view->configDevice( item->text() );
@@ -77,7 +77,7 @@ KMobile::KMobile()
connect(m_view, TQT_SIGNAL(signalChangeStatusbar(const TQString&)),
this, TQT_SLOT(changeStatusbar(const TQString&)));
- // restore all configured devices
+ // restore all configured tqdevices
restoreAll();
// setup the system tray
@@ -240,7 +240,7 @@ void KMobile::optionsPreferences()
void KMobile::renameDevice()
{
- // rename the current selected device
+ // rename the current selected tqdevice
TQIconViewItem *item = m_view->currentItem();
if (item)
@@ -297,7 +297,7 @@ void KMobile::addDevice()
ptr = list[index];
- // add the new device to the list
+ // add the new tqdevice to the list
if (!m_view->addNewDevice(m_config, ptr)) {
KMessageBox::error(this,
@@ -313,34 +313,34 @@ void KMobile::addDevice()
/*
* show dialog to user, in which he may choose and select one of the already
- * configured mobile devices.
+ * configured mobile tqdevices.
*/
@@ -384,7 +384,7 @@ KMobileDevice * KMobileFactory::chooseDeviceDialog( TQWidget *parent,
void KMobile::removeDevice()
{
- // remove the current selected device
+ // remove the current selected tqdevice
TQIconViewItem *item = m_view->currentItem();
if (item)
@@ -392,7 +392,7 @@ void KMobile::removeDevice()
void KMobile::configDevice()
{
- // configure the current selected device
+ // configure the current selected tqdevice
TQIconViewItem *item = m_view->currentItem();
if (item)